//
//  AdTiming.h
//  AdTiming SDK
//
//  Copyright 2017 AdTiming Inc. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <Foundation/Foundation.h>
#import "AdTimingAdType.h"


NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSInteger, AdTimingGender) {
    AdTimingGenderUnknown,
    AdTimingGenderMale,
    AdTimingGenderFemale,
};

typedef void(^initCompletionHandler)(NSError *_Nullable error);


@interface AdTiming : NSObject

/// Initializes AdTiming's SDK with all the ad types that are defined in the platform.
+ (void)initWithAppKey:(NSString*)appKey;

/// Initializes AdTiming's SDK with the requested ad types.
+ (void)initWithAppKey:(NSString *)appKey adType:(AdTimingAdType)initAdTypes;

/// Check that `AdTiming` has been initialized
+ (BOOL)isInitialized;

/// current SDK version
+ (NSString *)SDKVersion;

/// setUserConsent "NO" is Refuse，"YES" is Accepted. //GDPR
/// According to the GDPR, set method of this property must be called before "initWithAppKey:", or by default will collect user's information.
+ (void)setGDPRConsent:(BOOL)consent;

///According to the CCPA, set method of this property must be called before "initWithAppKey:", or by default will collect user's information.
+ (void)setUSPrivacyLimit:(BOOL)privacyLimit;

/// log enable,default is YES
+ (void)setLogEnable:(BOOL)logEnable;

/// Set this property to configure the user's age.
+ (void)setUserAge:(NSInteger)userAge;

/// Set the gender of the current user
+ (void)setUserGender:(AdTimingGender)userGender;

/// user in-app purchase
+ (void)userPurchase:(CGFloat)amount currency:(NSString*)currencyUnit;

/// send appsflyer conversion data for roas
+ (void)sendAFConversionData:(NSDictionary*)conversionInfo;

/// send appsflyer deep link data for roas
+ (void)sendAFDeepLinkData:(NSDictionary*)attributionData;

/// A tool to verify a successful integration of the AdTiming SDK and any additional adapters.
+ (void)validateIntegration;

///bidderToken
+ (NSString*)bidderToken;

@end

NS_ASSUME_NONNULL_END
