//
//  AdTimingAdsBanner.h
//  AdTimingiming SDK
//
//  Copyright 2017 AdTiming Inc. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <Foundation/Foundation.h>
#import "AdTimingAdsBannerDelegate.h"

NS_ASSUME_NONNULL_BEGIN

/// Banner Ad Size
typedef NS_ENUM(NSInteger, AdTimingAdsBannerType) {
    AdTimingAdsBannerTypeDefault = 0,       ///ad size: 320 x 50
    AdTimingAdsBannerTypeLarge = 1,         ///ad size: 320 x 100
    AdTimingAdsBannerTypeLeaderboard = 2    ///ad size: 728x90
};


/// Banner Ad layout attribute
typedef NS_ENUM(NSInteger, AdTimingAdsBannerLayoutAttribute) {
    AdTimingAdsBannerLayoutAttributeTop = 0,
    AdTimingAdsBannerLayoutAttributeLeft = 1,
    AdTimingAdsBannerLayoutAttributeBottom = 2,
    AdTimingAdsBannerLayoutAttributeRight = 3,
    AdTimingAdsBannerLayoutAttributeHorizontally = 4,
    AdTimingAdsBannerLayoutAttributeVertically = 5
};

/// A customized UIView to represent a AdTimingiming ad (banner ad).
@interface AdTimingAdsBanner : UIView

@property(nonatomic, readonly, nullable) NSString *placementID;

/// the delegate
@property (nonatomic, weak)id<AdTimingAdsBannerDelegate> delegate;

/// The banner's ad placement ID.
- (NSString*)placementID;

- (instancetype)initWithBannerType:(AdTimingAdsBannerType)type placementID:(NSString *)placementID;

- (instancetype)initWithBannerType:(AdTimingAdsBannerType)type placementID:(NSString *)placementID rootViewController:rootViewController;

/// set the banner position.
- (void)addLayoutAttribute:(AdTimingAdsBannerLayoutAttribute)attribute constant:(CGFloat)constant;

/// Begins loading the AdTimingAdsBanner content. And to show with default controller([UIApplication sharedApplication].keyWindow.rootViewController) when load success.
- (void)loadAndShow;

///load ad with bid payload
- (void)loadAndShowWithPayLoad:(NSString*)bidPayload;
@end

NS_ASSUME_NONNULL_END
