//
//  AdTimingAdsBannerDelegate.h
//  AdTiming SDK
//
//  Copyright 2017 AdTiming Inc. All rights reserved.
//
#import <Foundation/Foundation.h>

@class AdTimingAdsBanner;

NS_ASSUME_NONNULL_BEGIN

/// The methods declared by the AdTimingAdsBannerDelegate protocol allow the adopting delegate to respond to messages from the AdTimingAdsBanner class and thus respond to operations such as whether the ad has been loaded, the person has clicked the ad.
@protocol AdTimingAdsBannerDelegate<NSObject>

@optional

/// Sent when an ad has been successfully loaded.
- (void)adtimingBannerDidLoad:(AdTimingAdsBanner *)banner;

/// Sent after an AdTimingAdsBanner fails to load the ad.
- (void)adtimingBannerDidFailToLoad:(AdTimingAdsBanner *)banner withError:(NSError *)error;

/// Sent immediately before the impression of an AdTimingAdsBanner object will be logged.
- (void)adtimingBannerWillExposure:(AdTimingAdsBanner *)banner;

/// Sent after an ad has been clicked by the person.
- (void)adtimingBannerDidClick:(AdTimingAdsBanner *)banner;

/// Sent when a banner is about to present a full screen content
- (void)adtimingBannerWillPresentScreen:(AdTimingAdsBanner *)banner;

/// Sent after a full screen content has been dismissed.
- (void)adtimingBannerDidDismissScreen:(AdTimingAdsBanner *)banner;

 /// Sent when a user would be taken out of the application context.
- (void)adtimingBannerWillLeaveApplication:(AdTimingAdsBanner *)banner;

@end

NS_ASSUME_NONNULL_END
